<?php

namespace Drupal\pagedesigner_debug\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Undocumented class.
 */
class DebugForm extends FormBase {


  /**
   * Correction texts.
   */
  protected $texts = [
    'entity' => 'The entity field has to be corrected to @id.',
    'parent' => 'The parent field has to be corrected to @id.',
    'child' => 'The element needs to be removed from the parent with id @id.',
  ];

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'pagedesigner_debug_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['hint'] = [
      '#markup' => '<p>Not supported yet, use drush commands (pd_debug:check and pd_debug:correct).</p>',
    ];
    return $form;
    $form['general'] = [
      '#type' => 'details',
      '#title' => $this->t('Selection'),
      '#open' => TRUE,
    ];
    $options = [];

    $types = \Drupal::entityTypeManager()
      ->getStorage('node_type')
      ->loadMultiple();
    foreach ($types as $type) {
      $options[$type->id()] = $type->label();
    }
    $selected = $form_state->getValue('content_types');
    if (!empty($selected)) {
      $selected = array_filter(
      $selected, (
        function ($a) {
          return $a !== 0;
        }
      ));
    }

    $form['general']['content_types'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Content types'),
      '#options' => $options,
      '#default_value' => (!empty($selected)) ? $selected : [],
    ];

    $form['submit'] = [
      '#type' => 'button',
      '#value' => $this->t('Collect'),
    ];

    if (!empty($selected)) {
      $nids = \Drupal::entityQuery('node')->condition('type', $selected, 'IN')->execute();
      $checker = \Drupal::service('pagedesigner_debug.structure_debugger');
      $checker->checkStructure($nids);

      $form['results'] = [
        '#type' => 'details',
        '#title' => $this->t('Results'),
        '#open' => TRUE,
      ];

      $form['results']['findings'] = [
        '#type' => 'table',
        '#header' => [t('Element id'), t('Finding')],
        '#empty' => t('No corrections found.'),
        '#tableselect' => TRUE,
      ];

      foreach ($checker->getCorrections() as $delta => $correction) {
        $correctionKey = key($correction);
        $form['results']['findings'][$delta]['id'] = [
          '#plain_text' => $delta,
        ];
        $correctionText = [];
        if (is_array($correction[$correctionKey])) {
          foreach ($correction[$correctionKey] as $correctionValue) {
            $correctionText[] = t(
              $this->texts[$correctionKey],
              ['@id' => $correctionValue]
            );
          }
        }
        else {
          $correctionText[] = t(
            $this->texts[$correctionKey],
            ['@id' => $correction[$correctionKey]]
          );
        }

        // Some table columns containing raw markup.
        $form['results']['findings'][$delta]['description'] = [
          '#markup' => implode('<br />', $correctionText),
        ];

        $form['results']['corrections'] = [
          '#type' => 'checkboxes',
          '#title' => $this->t('Corrections'),
          '#options' => $checkOptions,
          '#default_value' => (!empty($form_state->getValue('corrections'))) ? $form_state->getValue('corrections') : $checkOptions,
        ];

        $form['actions']['apply'] = [
          '#type' => 'submit',
          '#value' => t('Apply corrections'),
          '#name' => 'apply_corrections',
          // TableSelect: Enable the built-in form validation for #tableselect for
          // this form button, so as to ensure that the bulk operations form cannot
          // be submitted without any selected items.
          '#tableselect' => FALSE,
        ];
      }
    }
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    if ($form_state->getTriggeringElement()['#name'] == 'apply_corrections') {
    }
  }

}
